import { useEffect } from 'react';
import { loader, useMonaco } from '@monaco-editor/react';
import { register_dolphindb_language } from '../index.js';
import { set_color_map } from '../tokenizer.js';
import use_is_unmounted from './use-is-unmounted.js';
let monaco_initialized = false;
let init_monaco_promise = null;
export function use_init_dolphindb_monaco({ beforeMonacoInit, onMonacoInit, onMonacoInitFailed, dolphinDBLanguageOptions }) {
    const isUnmountedRef = use_is_unmounted();
    function setInitMonacoPromiseThenAndCatch(p) {
        p.then(monaco => {
            if (!isUnmountedRef.current)
                onMonacoInit?.(monaco);
        })
            .catch(err => {
            onMonacoInitFailed?.(err);
        })
            .finally(() => {
            init_monaco_promise = null;
        });
    }
    // 已完成初始化
    if (monaco_initialized)
        return;
    // 正在初始化
    if (init_monaco_promise) {
        setInitMonacoPromiseThenAndCatch(init_monaco_promise);
        return;
    }
    // 未初始化
    init_monaco_promise = (async () => {
        await beforeMonacoInit?.();
        const monaco = await loader.init();
        await register_dolphindb_language(monaco, dolphinDBLanguageOptions);
        await document.fonts.ready;
        monaco_initialized = true;
        return monaco;
    })();
    setInitMonacoPromiseThenAndCatch(init_monaco_promise);
}
/** update editor on options change */
export function use_dolphindb_monaco_options({ theme }) {
    const monaco = useMonaco();
    useEffect(() => {
        if (monaco)
            set_color_map(monaco, theme ?? 'light');
    }, [monaco, theme]);
}
//# sourceMappingURL=shared.js.map